<?php
/**
 * Music Club Pro functions and definitions
 *
 * @package Music Club Pro
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
function content($limit) {
$content = explode(' ', get_the_excerpt(), $limit);
if (count($content)>=$limit) {
array_pop($content);
$content = implode(" ",$content).'...';
} else {
$content = implode(" ",$content);
}	
$content = preg_replace('/\[.+\]/','', $content);
$content = apply_filters('the_content', $content);
$content = str_replace(']]>', ']]&gt;', $content);
return $content;
}
//Excerpt limit function
function custom_excerpt_length( $length ) {
	return 100;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

if ( ! function_exists( 'music_club_pro_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function music_club_pro_setup() {

	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */

	load_theme_textdomain( 'music-club-pro', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_filter('widget_text', 'do_shortcode');
	add_image_size('homepage-thumb',240,145,true);	
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'music-club-pro' ),
		'footer' => __( 'Footer Menu', 'music-club-pro' ),		
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_editor_style( 'editor-style.css' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
endif; // music_club_pro_setup
add_action( 'after_setup_theme', 'music_club_pro_setup' );

function music_club_pro_widgets_init() {

	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'music-club-pro' ),
		'description'   => __( 'Appears on blog page sidebar', 'music-club-pro' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar Main', 'music-club-pro' ),
		'description'   => __( 'Appears on page sidebar', 'music-club-pro' ),
		'id'            => 'sidebar-main',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );	
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 1', 'music-club-pro' ),
		'description'   => __( 'Appears on footer', 'music-club-pro' ),
		'id'            => 'footer-1',
		'before_widget' => '<div id="%1$s" class="widget-column-1">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 2', 'music-club-pro' ),
		'description'   => __( 'Appears on footer', 'music-club-pro' ),
		'id'            => 'footer-2',
		'before_widget' => '<div id="%1$s" class="widget-column-2">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 3', 'music-club-pro' ),
		'description'   => __( 'Appears on footer', 'music-club-pro' ),
		'id'            => 'footer-3',
		'before_widget' => '<div id="%1$s" class="widget-column-3">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 4', 'music-club-pro' ),
		'description'   => __( 'Appears on footer', 'music-club-pro' ),
		'id'            => 'footer-4',
		'before_widget' => '<div id="%1$s" class="widget-column-4">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );

}
add_action( 'widgets_init', 'music_club_pro_widgets_init' );

define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/' );
require_once get_template_directory() . '/inc/options-framework.php';

function music_club_pro_scripts() {	
	wp_enqueue_style( 'music-club-pro-gfonts-lato', '//fonts.googleapis.com/css?family=Lato:400,300,300italic,400italic,700,700italic' );	

	if( of_get_option('bodyfontface',true) != '' ){
		wp_enqueue_style( 'music-club-pro-gfonts-body', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('bodyfontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	
	//header style 1
	if( of_get_option('logofontface',true) != '' ){
		wp_enqueue_style( 'music-club-pro-gfonts-logo', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('logofontface',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if ( of_get_option('navfontface', true) != '' ) {
		wp_enqueue_style( 'music-club-pro-gfonts-nav', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('navfontface',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	
	//header style 2
	if( of_get_option('logofontface_style2',true) != '' ){
		wp_enqueue_style( 'music-club-pro-gfonts-logo', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('logofontface_style2',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if ( of_get_option('navfontface_style2', true) != '' ) {
		wp_enqueue_style( 'music-club-pro-gfonts-nav', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('navfontface_style2',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	
	//header style 3
	if( of_get_option('logofontface_style3',true) != '' ){
		wp_enqueue_style( 'music-club-pro-gfonts-logo', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('logofontface_style3',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if ( of_get_option('navfontface_style3', true) != '' ) {
		wp_enqueue_style( 'music-club-pro-gfonts-nav', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('navfontface_style3',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	
	
	if ( of_get_option('headfontface', true) != '' ) {
		wp_enqueue_style( 'music-club-pro-gfonts-heading', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('headfontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	} 
	if ( of_get_option('sectiontitlefontface', true) != '' ) {
		wp_enqueue_style( 'music-club-pro-gfonts-sectiontitle', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('sectiontitlefontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	} 
	if ( of_get_option('slidetitlefontface', true) != '' ) {
		wp_enqueue_style( 'music-club-pro-gfonts-slidetitle', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('slidetitlefontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	} 
	if ( of_get_option('slidedesfontface', true) != '' ) {
		wp_enqueue_style( 'music-club-pro-gfonts-slidedes', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('slidedesfontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	}	

	wp_enqueue_style( 'music-club-pro-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'music-club-pro-editor-style', get_template_directory_uri().'/editor-style.css' );
	wp_enqueue_style( 'music-club-pro-base-style', get_template_directory_uri().'/css/default.css' );	
	if ( is_home() || is_front_page() ) { 
	wp_enqueue_style( 'music-club-pro-nivo-style', get_template_directory_uri().'/css/nivo-slider.css' );
	wp_enqueue_script( 'music-club-pro-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	}	

	wp_enqueue_script( 'music-club-pro-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );		
	wp_enqueue_style( 'music-club-pro-fontawesome-all-style', get_template_directory_uri().'/fontsawesome/css/fontawesome-all.css' );
	
				
	wp_enqueue_style( 'music-club-pro-animation', get_template_directory_uri().'/css/animation.css' );
	wp_enqueue_style( 'music-club-pro-hover', get_template_directory_uri().'/css/hover.css' );
	wp_enqueue_style( 'music-club-pro-hover-min', get_template_directory_uri().'/css/hover-min.css' );
	wp_enqueue_script( 'music-club-pro-testimonialsminjs', get_template_directory_uri().'/testimonialsrotator/js/jquery.quovolver.min.js', array('jquery') );
	wp_enqueue_style( 'music-club-pro-testimonialslider-style', get_template_directory_uri().'/testimonialsrotator/js/tm-rotator.css' );	
	wp_enqueue_style( 'music-club-pro-responsive-style', get_template_directory_uri().'/css/responsive.css' );		
	wp_enqueue_style( 'music-club-pro-owl-style', get_template_directory_uri().'/testimonialsrotator/js/owl.carousel.css' );
	wp_enqueue_script( 'music-club-pro-owljs', get_template_directory_uri().'/testimonialsrotator/js/owl.carousel.js', array('jquery') );
	
	wp_enqueue_script( 'music-club-pro-counterup', get_template_directory_uri().'/counter/js/jquery.counterup.min.js', array('jquery') );
	wp_enqueue_script( 'music-club-pro-waypoints', get_template_directory_uri().'/counter/js/waypoints.min.js', array('jquery') );
	
	
	// mixitup script
	wp_enqueue_style( 'music-club-pro-mixitup-style', get_template_directory_uri().'/mixitup/style-mixitup.css' );
	wp_enqueue_script( 'music-club-pro-jquery_013-script', get_template_directory_uri() . '/mixitup/jquery_013.js', array('jquery') );
	wp_enqueue_script( 'music-club-pro-jquery_003-script', get_template_directory_uri() . '/mixitup/jquery_003.js', array('jquery') );
	wp_enqueue_script( 'music-club-pro-screen-script', get_template_directory_uri() . '/mixitup/screen.js', array('jquery') );
	// prettyPhoto script
	wp_enqueue_style( 'music-club-pro-prettyphoto-style', get_template_directory_uri().'/mixitup/prettyPhotoe735.css' );
	wp_enqueue_script( 'music-club-pro-prettyphoto-script', get_template_directory_uri() . '/mixitup/jquery.prettyPhoto5152.js', array('jquery') );
	
	//Client Logo Rotator
	wp_enqueue_style( 'music-club-pro-flexiselcss', get_template_directory_uri().'/css/flexiselcss.css' );	
	wp_enqueue_script( 'music-club-pro-flexisel', get_template_directory_uri() . '/js/jquery.flexisel.js', array('jquery') );
	
	//Popup Video
	wp_enqueue_style( 'music-club-pro-youtube-popup', get_template_directory_uri().'/popupvideo/grt-youtube-popup.css' );	
	wp_enqueue_script( 'music-club-pro-youtube-popup', get_template_directory_uri() . '/popupvideo/grt-youtube-popup.js', array('jquery') );
	
	if( of_get_option('scrollanimation',true) != true) {
		wp_enqueue_style( 'music-club-pro-animation-style', get_template_directory_uri().'/css/animation-style.css' );
		wp_enqueue_script( 'music-club-pro-custom-animation', get_template_directory_uri() . '/js/custom-animation.js', array('jquery') );	
	}
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'music_club_pro_scripts' );

function media_css_hook(){
?>
    	
    	<script>
		jQuery(window).bind('scroll', function() {
	var wwd = jQuery(window).width();
	if( wwd > 981 ){
		var navHeight = jQuery( window ).height() - 575;
		<?php if( of_get_option('headstick',true) != '') { ?>
		if (jQuery(window).scrollTop() > navHeight) {
			jQuery(".site-header").addClass('fixed');
		}else {
			jQuery(".site-header").removeClass('fixed');
		}
		<?php } ?>
	}
});		

<?php if ( is_home() || is_front_page() ) { ?>
					
		jQuery(window).load(function() {
        jQuery('#slider').nivoSlider({
        	effect:'<?php echo of_get_option('slideefect',true); ?>', //sliceDown, sliceDownLeft, sliceUp, sliceUpLeft, sliceUpDown, sliceUpDownLeft, fold, fade, random, slideInRight, slideInLeft, boxRandom, boxRain, boxRainReverse, boxRainGrow, boxRainGrowReverse
		  	animSpeed: <?php echo of_get_option('slideanim',true); ?>,
			pauseTime: <?php echo of_get_option('slidepause',true); ?>,
			directionNav: <?php echo of_get_option('slidenav',true); ?>,
			controlNav: <?php echo of_get_option('slidepage',true); ?>,
			pauseOnHover: <?php echo of_get_option('slidepausehover',true); ?>,
    });
});

<?php } ?>

jQuery(window).load(function() {   
  jQuery('.owl-carousel').owlCarousel({
    loop:true,	
	autoplay: <?php echo of_get_option('testimonialsautoplay',true); ?>,
	autoplayTimeout: <?php echo of_get_option('testimonialsrotatingspeed',true); ?>,
    margin:0,
    nav:false,
	dots: true,
    responsive:{
        0:{
            items:1
        },
        600:{
            items:1
        },
        1000:{
            items:1
        }
    }
})
    
  });


jQuery(document).ready(function() {
  
  jQuery('.link').on('click', function(event){
    var $this = jQuery(this);
    if($this.hasClass('clicked')){
      $this.removeAttr('style').removeClass('clicked');
    } else{
      $this.css('background','#7fc242').addClass('clicked');
    }
  });
 
});
		</script>
<?php   
}
add_action('wp_head','media_css_hook'); 


function music_club_pro_custom_head_codes() { 
	if ( function_exists('of_get_option') ){
		if ( of_get_option('style2', true) != '' ) {
			echo "<style>". esc_html( of_get_option('style2', true) ) ."</style>";
		}
		echo "<style>";		
		if ( of_get_option('bodyfontcolor', true) != '' ) {
			echo 'body, .contact-form-section .address,  .accordion-box .acc-content{color:'. esc_html( of_get_option('bodyfontcolor', true) ) .';}';
		}
		if( of_get_option('bodyfontface', true) != '' || of_get_option('bodyfontsize',true) != ''){
			echo "body{font-family:".of_get_option('bodyfontface')."; font-size:".of_get_option('bodyfontsize',true).";}";
		}
			
			 
		if( of_get_option('sectiontitlefontface',true) != '' || of_get_option('sectitlesize',true) != '' || of_get_option('sectitlecolor',true) != '' ){
			echo "h2.section_title, h3.section_title{ font-family:".of_get_option('sectiontitlefontface',true)."; font-size:".of_get_option('sectitlesize',true)."; color:".of_get_option('sectitlecolor',true)."; }";
		}
		
		if( of_get_option('sectiontitlefontface',true) != '' ){
			echo ".counter-column{ font-family:".of_get_option('sectiontitlefontface',true)."; }";
		}
				
		if ( of_get_option('linkhovercolor', true) != '' ) {
			echo 'a:hover, .slide_toggle a:hover{color:'. esc_html( of_get_option('linkhovercolor', true) ) .';}';
		}			
		if( of_get_option('foottitlecolor', true) != '' || of_get_option('ftfontsize', true) != '' ){
			echo ".footer h5{color:".of_get_option('foottitlecolor', true)."; font-size:".of_get_option('ftfontsize', true)."; }";
		}
		
		if( of_get_option('designcolor', true) != ''){
			echo ".design-by{color:".of_get_option('designcolor',true)."}";
		}		
						
		
		if ( of_get_option('sbplyerbgcolor', true) != '' ) {
			echo "#topvideo_player {background-color:".of_get_option('sbplyerbgcolor',true).";}";
		}			
		if ( of_get_option('secondsecbgcolor', true) != '' ) {
			echo "#aboutus_section {background-color:".of_get_option('secondsecbgcolor',true).";}";
		}
		if ( of_get_option('ourservicesbgcolor', true) != '' ) {
			echo "#servicespanel {background-color:".of_get_option('ourservicesbgcolor',true).";}";
		}			
		
				
		
		if( of_get_option('btntxtcolor', true) != ''){
			echo ".button, #commentform input#submit, input.search-submit, .post-password-form input[type=submit], p.read-more a, .pagination ul li span, .pagination ul li a, .headertop .right a, .wpcf7 form input[type='submit'], #sidebar .search-form input.search-submit{ color:". of_get_option('btntxtcolor', true) ."; }";
		}
		if( of_get_option('btnbghvcolor',true) != '' || of_get_option('btntxthvcolor', true) != '' ){
			echo "#commentform input#submit:hover, input.search-submit:hover, .post-password-form input[type=submit]:hover, p.read-more a:hover, .pagination ul li .current, .pagination ul li a:hover,.headertop .right a:hover, .wpcf7 form input[type='submit']:hover{background-color:".of_get_option('btnbghvcolor',true)."; color:". esc_html( of_get_option('btntxthvcolor', true) ) .";}";
		}		
		if( of_get_option('btntxtcolor', true) != ''){
			echo "a.morebutton{ color:". of_get_option('btntxtcolor', true) ."; }";
		}
		if( of_get_option('btnbghvcolor',true) != '' || of_get_option('btntxthvcolor', true) != '' ){
			echo "a.morebutton:hover{background-color:".of_get_option('btnbghvcolor',true)."; color:". esc_html( of_get_option('btntxthvcolor', true) ) .";}";
		}
		
		if ( of_get_option('widgetboxfontcolor', true) != '' ) {
		echo "aside.widget{ color:".of_get_option('widgetboxfontcolor', true).";  }";
		}			
		if ( of_get_option('wdgttitleccolor', true) != '' ) {
			echo "h3.widget-title{ color:".of_get_option('wdgttitleccolor', true).";}";
		}				
		if ( of_get_option('footerbgcolor', true) != '' || of_get_option('footdesccolor', true) != '' ) {
		echo "#footer-wrapper{background-color:".of_get_option('footerbgcolor', true)."; color:".of_get_option('footdesccolor', true).";}";
		}
		
		if ( of_get_option('footerbgimage', true) != '') {
		echo "#footer-wrapper{background: url(".of_get_option('footerbgimage', true).") no-repeat; background-size: 100% 100% !important; }";
		}
					
		if ( of_get_option('footdesccolor', true) != '' ) {
			echo ".contactdetail a{color:".of_get_option('footdesccolor', true)."; }";
		}			
				
		if( of_get_option('sldpagebg',true) != ''){
			echo ".nivo-controlNav a{background-color:".of_get_option('sldpagebg',true)."}";
		}		
		
		if( of_get_option('sidebarfontcolor',true) != '' ){
			echo "#sidebar ul li a{color:".of_get_option('sidebarfontcolor',true)."; }";
		}		
		
		if ( of_get_option('slidetitlefontface', true) != '' || of_get_option('slidetitlecolor', true) != '' || of_get_option('slidetitlefontsize', true) != '') {
		echo ".nivo-caption h2{ font-family:".of_get_option('slidetitlefontface', true)."; color:".of_get_option('slidetitlecolor', true)."; font-size:".of_get_option('slidetitlefontsize', true).";}";
		}
		
		if ( of_get_option('slidedesfontface', true) != '' || of_get_option('slidedesccolor', true) != '' || of_get_option('slidedescfontsize', true) != '') {
		echo ".nivo-caption p{font-family:".of_get_option('slidedesfontface', true)."; color:".of_get_option('slidedesccolor', true)."; font-size:".of_get_option('slidedescfontsize', true).";}";
		}
					
		if ( of_get_option('copylinkshover', true) != '' ) {
		echo ".copyright-wrapper a:hover{ color: ".of_get_option('copylinkshover', true)."; }";
		}	
		
		if ( of_get_option('togglemenucolor', true) != '' ) {
		echo ".toggle a{ color:".of_get_option('togglemenucolor', true)."; }";
		}
		
		
		
/* Heading */
		if( of_get_option('headfontface', true) != '' ){
			echo "h1,h2,h3,h4,h5,h6{ font-family:".of_get_option('headfontface',true)."; }";
		}		
		if ( of_get_option('h1fontsize', true) != '' || of_get_option('h1fontcolor', true) != '' ) {
			echo "h1{ font-size:".of_get_option('h1fontsize', true)."; color:".of_get_option('h1fontcolor', true).";}";
		}
		if ( of_get_option('h2fontsize', true) != '' || of_get_option('h2fontcolor', true) != '' ) {
			echo "h2{ font-size:".of_get_option('h2fontsize', true)."; color:".of_get_option('h2fontcolor', true).";}";
		}		
		if ( of_get_option('h3fontsize', true) != '' || of_get_option('h3fontcolor', true) != '' ) {
			echo "h3{ font-size:".of_get_option('h3fontsize', true)."; color:".of_get_option('h3fontcolor', true).";}";
		}		
		if ( of_get_option('h4fontsize', true) != '' || of_get_option('h4fontcolor', true) != '' ) {
			echo "h4{ font-size:".of_get_option('h4fontsize', true)."; color:".of_get_option('h4fontcolor', true).";}";
		}		
		if ( of_get_option('h5fontsize', true) != '' || of_get_option('h5fontcolor', true) != '' ) {
			echo "h5{font-size:".of_get_option('h5fontsize', true)."; color:".of_get_option('h5fontcolor', true).";}";
		}		
		if ( of_get_option('h6fontsize', true) != '' || of_get_option('h6fontcolor', true) != '' ) {
			echo "h6{ font-size:".of_get_option('h6fontsize', true)."; color:".of_get_option('h6fontcolor', true).";}";
		}					
			
		if ( of_get_option('footsocialcolor', true) != '' ) {
			echo "#footer-wrapper .social-icons a{ color:".of_get_option('footsocialcolor', true)."; }";
		}		
		
				
		if ( of_get_option('galleryfiltercolor', true) != '' ) {
			echo "ul.portfoliofilter li a{ color:".of_get_option('galleryfiltercolor', true)."; }";
		}			
		
		if ( of_get_option('gallerytitlecolorhv', true) != '' ) {
			echo ".holderwrap h5{ color:".of_get_option('gallerytitlecolorhv', true)."; }";
		}
		if ( of_get_option('gallerytitlecolorhv', true) != '' ) {
			echo ".holderwrap h5::after{ background-color:".of_get_option('gallerytitlecolorhv', true)."; }";
		}		
		
				
		//Testimonials CSS		
		if ( of_get_option('testimonialdescriptioncolor', true) != '' ) {
			echo "#clienttestiminials .item{ color:".of_get_option('testimonialdescriptioncolor', true)."; }";
		}			
				
		if ( of_get_option('footerpoststitlecolor', true) != '' ) {
			echo "ul.recent-post li h6 a{ color:".of_get_option('footerpoststitlecolor', true)."; }";
		}
		
		if( of_get_option('logoheight',true) != '' ){
			echo ".logo img{height:".of_get_option('logoheight',true)."px;}";
		}
		
		//Header Style 1 ( Default )CSS			
		
		if( of_get_option('headerlayout', true) == 'header1' ){
		
		if( of_get_option('logofontface',true) != '' || of_get_option('logofontcolor',true) != '' || of_get_option('logofontsize',true) != ''){
			echo ".logo h1 {font-family:".of_get_option('logofontface').";color:".of_get_option('logofontcolor',true).";font-size:".of_get_option('logofontsize',true)."}";
		}
		
		if( of_get_option('logotaglinecolor',true) != '' ){
			echo ".tagline{color:".of_get_option('logotaglinecolor',true).";}";
		}
		if( of_get_option('logoheight',true) != '' ){
			echo ".logo img{height:".of_get_option('logoheight',true)."px;}";
		}		
				
		if ( of_get_option('navlibdcolor', true) != '') {
			echo ".sitenav ul li ul li{border-color:".of_get_option('navlibdcolor', true).";}";
		}
		if ( of_get_option('navfontface', true) != '' || of_get_option('navfontsize',true) != '' ) {
			echo '.sitenav ul{font-family:\''. esc_html( of_get_option('navfontface', true) ) .'\', sans-serif;font-size:'.of_get_option('navfontsize',true).'}';
		}
				
		if ( of_get_option('navfontcolor', true) != '' ) {
			echo '.sitenav ul li a, .sitenav ul li.current_page_item ul.sub-menu li a, .sitenav ul li.current-menu-parent ul.sub-menu li a{color:'. esc_html( of_get_option('navfontcolor', true) ) .';}';
		}		
		
		if( of_get_option('socialfontcolor',true) != '' ){
			echo ".header-top .social-icons a{ color:".of_get_option('socialfontcolor',true).";}";
		}					
		
		if ( of_get_option('headertopfontcolor', true) != '') {
			echo ".header-top { color:".of_get_option('headertopfontcolor',true).";}";
		}		
		
		if ( of_get_option('headerbgcolor', true) != '' ) {
			echo ".logonavigation, .sitenav ul li:hover > ul, .logo {background-color:".of_get_option('headerbgcolor',true).";}";
		}
		}	
		
		//Header Style 2 CSS
		if( of_get_option('headerlayout', true) == 'header2' ){
		if( of_get_option('logofontface_style2',true) != '' || of_get_option('logofontcolor_style2',true) != '' || of_get_option('logofontsize_style2',true) != ''){
			echo ".logo h1 {font-family:".of_get_option('logofontface_style2').";color:".of_get_option('logofontcolor_style2',true).";font-size:".of_get_option('logofontsize_style2',true)."}";
		}
		
		if( of_get_option('logotaglinecolor_style2',true) != '' ){
			echo ".tagline{color:".of_get_option('logotaglinecolor_style2',true).";}";
		}				
				
		if ( of_get_option('navlibdcolor_style2', true) != '') {
			echo ".sitenav ul li ul li{border-color:".of_get_option('navlibdcolor_style2', true).";}";
		}
		if ( of_get_option('navfontface_style2', true) != '' || of_get_option('navfontsize_style2',true) != '' ) {
			echo '.sitenav ul{font-family:\''. esc_html( of_get_option('navfontface_style2', true) ) .'\', sans-serif;font-size:'.of_get_option('navfontsize_style2',true).'}';
		}		
		if ( of_get_option('navfontcolor_style2', true) != '' ) {
			echo '.sitenav ul li a, .sitenav ul li.current_page_item ul.sub-menu li a, .sitenav ul li.current-menu-parent ul.sub-menu li a{color:'. esc_html( of_get_option('navfontcolor_style2', true) ) .';}';
		}
		
		if( of_get_option('socialfontcolor_style2',true) != '' ){
			echo ".header-top .social-icons a{ color:".of_get_option('socialfontcolor_style2',true).";}";
		}					
		
		if ( of_get_option('headertopfontcolor_style2', true) != '') {
			echo ".header-top { color:".of_get_option('headertopfontcolor_style2',true).";}";
		}		
		
		if ( of_get_option('headerbgcolor_style2', true) != '' ) {
			echo ".logonavigation, .sitenav ul li:hover > ul, .logo {background-color:".of_get_option('headerbgcolor_style2',true).";}";
		}
		}		
		
		//Header Style 3 CSS
		if( of_get_option('headerlayout', true) == 'header3' ){
		if( of_get_option('logofontface_style3',true) != '' || of_get_option('logofontcolor_style3',true) != '' || of_get_option('logofontsize_style3',true) != ''){
			echo ".logo h1 {font-family:".of_get_option('logofontface_style3').";color:".of_get_option('logofontcolor_style3',true).";font-size:".of_get_option('logofontsize_style3',true)."}";
		}
		
		if( of_get_option('logotaglinecolor_style3',true) != '' ){
			echo ".tagline{color:".of_get_option('logotaglinecolor_style3',true).";}";
		}				
				
		if ( of_get_option('navlibdcolor_style3', true) != '') {
			echo ".sitenav ul li ul li{border-color:".of_get_option('navlibdcolor_style3', true).";}";
		}
		if ( of_get_option('navfontface_style3', true) != '' || of_get_option('navfontsize_style3',true) != '' ) {
			echo '.sitenav ul{font-family:\''. esc_html( of_get_option('navfontface_style3', true) ) .'\', sans-serif;font-size:'.of_get_option('navfontsize_style3',true).'}';
		}		
		if ( of_get_option('navfontcolor_style3', true) != '' ) {
			echo '.sitenav ul li a, .sitenav ul li.current_page_item ul.sub-menu li a, .sitenav ul li.current-menu-parent ul.sub-menu li a{color:'. esc_html( of_get_option('navfontcolor_style3', true) ) .';}';
		}		
		if( of_get_option('socialfontcolor_style3',true) != '' ){
			echo ".header-top .social-icons a{ color:".of_get_option('socialfontcolor_style3',true).";}";
		}					
		
		if ( of_get_option('headertopfontcolor_style3', true) != '') {
			echo ".header-top { color:".of_get_option('headertopfontcolor_style3',true).";}";
		}		
		
		if ( of_get_option('headerbgcolor_style3', true) != '' ) {
			echo ".logonavigation, .sitenav ul li:hover > ul, .logo {background-color:".of_get_option('headerbgcolor_style3',true).";}";
		}
		}
		
		//Default Color scheme
		$teamhex = of_get_option('colorscheme',true); 
		list($r,$g,$b) = sscanf($teamhex,'#%02x%02x%02x');
		if ( of_get_option('colorscheme', true) != '' ) {
			echo ".team_content_fixer{background-color:rgba(".$r.",".$g.",".$b.",0.8);}";
		}	
		
		//Color scheme for one click background color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo "#commentform input#submit, 
			.button,
			input.search-submit,			
			.post-password-form input[type='submit'], 
			.wpcf7 form input[type='submit'], 
			#commentform input#submit:hover, 
			input.search-submit:hover, 
			.post-password-form input[type=submit]:hover,
			.wpcf7 form input[type='submit']:hover,				 
			p.read-more a,			
			.header-top .social-icons a:hover, 
			#topvideo_player .ai-wrap .ai-audio-control,
			#topvideo_player .ai-wrap .ai-volume-bar.ai-volume-bar-active::before,
			#topvideo_player .ai-wrap .ai-track-progress,
			.released_list .owl-prev, 
			.released_list .owl-next,
			.released_list .item,
			.pagination ul li span, 
			.pagination ul li a, 
			.headertop .right a, 			
			#sidebar .search-form input.search-submit,
			.nivo-controlNav a.active,			
			.holderwrap,
			.owl-controls .owl-dot.active,			
			p.read-more a:hover, 			
			.pagination ul li .current, 
			.pagination ul li a:hover,
			.headertop .right a:hover, 				
			#footer-wrapper .social-icons a,
			.toggle a,
			.pagemore:hover,
			.gradientbtn,					
			.newspostdate,
			.news-box:hover .newsmorebtn,
			#section7 .button:hover,			
			.blogrightsidebar .post-thumb,
			.news-box .news-thumb,
			.audio_album_list .audiothumbbx,
			.bloggridlayout .post-thumb,			
			.woocommerce ul.products li.product a.add_to_cart_button:hover,
			.nbs-flexisel-nav-left:hover, .nbs-flexisel-nav-right:hover,			
			.woocommerce ul.products li.product:hover,			
			.teammember-list:hover .degination,
			.woocommerce span.onsale,			
			.nivo-caption .button:hover,		
			#teampanel .owl-prev:hover, #teampanel .owl-next:hover,			
			.moreicon .i{ background-color:".of_get_option('colorscheme', true)."; }";
		}
		
				
		//Color scheme for one click font color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo "a,			
			.sitenav ul li a:hover, 
			.sitenav ul li.current_page_item a, 
			.sitenav ul li.current_page_item ul li a:hover,
			.sitenav ul li.current-menu-parent a, 
			.sitenav ul li:hover,
			.sitenav ul li.current_page_item ul.sub-menu li a:hover, 
			.sitenav ul li.current-menu-parent ul.sub-menu li a:hover,
			.sitenav ul li.current-menu-parent ul.sub-menu li.current_page_item a,
			.sitenav ul li:hover,			
			h3.style2 span,					
			.contactdetail a:hover, 
			.footer h5 span, 
			.news-box:hover h5 a,
			.footer ul li a:hover, 
			.footer ul li.current_page_item a, 
			div.recent-post a:hover,		
			.copyright-wrapper a,	
			.audio_album_list:hover h4 a,
			.eventtexttitle a:hover,				
			.slide_toggle a,			
			#sidebar ul li a:hover,			
			.teammember-content span,		
			.btnstyle2:hover,
			.slidereadmore:hover,				
			h2.section_title span,			
			h3.post-title a:hover,
			.aboutus_imgcolumn h3 span,		
			.woocommerce table.shop_table th, 
			.woocommerce-page table.shop_table th,
			#clienttestiminials h6 a,			
			ul.portfoliofilter li a.selected, 
			ul.portfoliofilter li a:hover,
			ul.portfoliofilter li:hover a,			
			.news-box .postdate,
			.tabs-wrapper ul.tabs li a.selected, 
			.tabs-wrapper ul.tabs li:hover a,
			.news_left_content h4 a:hover,
			.footer ul li a:hover, .footer ul li.current_page_item a,			
			.woocommerce ul.products li.product h2:hover,		
			.woocommerce div.product p.price, 
			.woocommerce div.product span.price{ color:".of_get_option('colorscheme', true)."; }";
		}
		
		
		//Color scheme for one click border color
		if ( of_get_option('colorscheme', true) != '' ) {
			echo ".aboutus_wrap h3::after,			
			h3.style2,	
			.slidereadmore:hover,			
			.member-social-icon a:hover,			
			.btnstyle2:hover,			
			ul.portfoliofilter li:hover a{ border-color:".of_get_option('colorscheme', true)."; }";
		}		
		
		
		echo "</style>";
	}
}
add_action('wp_head', 'music_club_pro_custom_head_codes');


//pagination
function music_club_pro_pagination() {
	global $wp_query;
	$big = 12345678;
	$page_format = paginate_links( array(
	    'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	    'format' => '?paged=%#%',
	    'current' => max( 1, get_query_var('paged') ),
	    'total' => $wp_query->max_num_pages,
	    'type'  => 'array'
	) );
	if( is_array($page_format) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $page_format as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	}
}


//pagination
function music_club_pro_custom_blogpost_pagination( $wp_query ){
	$big = 999999999; // need an unlikely integer
	if ( get_query_var('paged') ) { $pageVar = 'paged'; }
	elseif ( get_query_var('page') ) { $pageVar = 'page'; }
	else { $pageVar = 'paged'; }
	$pagin = paginate_links( array(
		'base' 			=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' 		=> '?'.$pageVar.'=%#%',
		'current' 		=> max( 1, get_query_var($pageVar) ),
		'total' 		=> $wp_query->max_num_pages,
		'prev_text'		=> '&laquo; Prev',
		'next_text' 	=> 'Next &raquo;',
		'type'  => 'array'
	) ); 
	if( is_array($pagin) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $pagin as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	} 
}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load custom functions file.
 */
require get_template_directory() . '/inc/custom-functions.php';


/**
 * Include the Plugin_Activation class.
 */
require_once dirname( __FILE__ ) . '/class-plugin-activation.php';
add_action( 'tgmpa_register', 'music_club_pro_register_required_plugins' );
 
function music_club_pro_register_required_plugins() {
	$plugins = array(
		array(
			'name'      => 'AudioIgniter',
			'slug'      => 'audioigniter',
			'required'  => false,
		),
 
	);

	$config = array(
		'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'install-plugins', 	   // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}